@@ -21,16 +21,13 @@
 # Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 
 import os, time
-import Lib3
+from TheMingServer import consts, lib
 
 class Incoming:
 	NAME = "Incoming"
 
-	def __init__(self, lib, consts, debug):
-		self.lib = lib
-		self.debug = debug
-		self.INCOMING_MAX = consts.INCOMING_MAX
-		return
+	def __init__(self):
+		pass
 
 	def store(self, form, file):
 		# check incoming sizes and generate sum
@@ -38,13 +35,13 @@ class Incoming:
 		new = {}
 		now = time.time()
 		new["stamp"] = `now`
-		new["id"] = self.lib.form_token(now)
+		new["id"] = lib.form_token(now)
 		for key in form.keys():
-			if (key not in ["page", "file", "debug", "incoming", "submit", "params"]):
+			if key not in ["page", "file", "debug", "incoming", "submit", "params"]:
 				text = "text" in key
 				length = len(form[key].value)
-				if (((text) and (length > self.INCOMING_MAX )) or
-					((not text) and length > 128 )):
+				if (text and length > consts.INCOMING_MAX or
+					(not text) and length > 128):
 					return "Submission contains fields which exceed acceptable size."
 				new[key] = form[key].value
 				sum += length
@@ -56,7 +53,7 @@ class Incoming:
 			address = `now`
 		new["address"] = address
 		# get old by stamp
-		old = self.lib.get_dict(file)
+		old = lib.get_dict(file)
 		# check for uniqueness
 		for key in old.keys():
 			try:
@@ -67,12 +64,12 @@ class Incoming:
 				address2 = old[key]["address"]
 			except:
 				address2 = `time.time()`
-			if ((address == address2) and
-				(`sum` == sum2)):
+			if (address == address2 and
+				`sum` == sum2):
 				return "Duplicate submission"
 		# if unique write to file_max
 		old[`now`] = new
-		self.lib.write_data(old, file)
+		lib.write_data(old, file)
 		if not old:
 			os.chmod(file, 0666)
 		return ""
