@@ -21,20 +21,15 @@
 # Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 
 import time
-import Constants
+from TheMingServer import consts, debug
 
 class Lib3:
 	NAME = "Lib3"
 	CONTENT = "content"
 	ORDER = "_order"
 
-	def __init__(self, debug):
-		self.debug = debug
-		c = Constants.Constants()
-		self.DATA = c.DATA				# for DirectSets
-		self.FILES = c.FILES
-		self.FILE_MAX = c.FILE_MAX
-		return
+	def __init__(self):
+		pass
 
 	def date_stamp(self):
 		tmp = time.ctime(time.time())
@@ -53,10 +48,10 @@ class Lib3:
 		try:
 			lines = self.get_lines(file)
 			length = len(lines)
-			while (i < length):
+			while i < length:
 				entry = {}
-				while (lines[i] != "---\n"):
-					if ("|" not in lines[i]):
+				while lines[i] != "---\n":
+					if "|" not in lines[i]:
 						entry[last] = entry[last] + "\n" + lines[i].strip()
 					else:
 						tokens = lines[i].split("|")
@@ -90,11 +85,11 @@ class Lib3:
 		with key
 		"""
 		import os
-		sites = data+os.sep+"sites"
+		sites = data + os.sep + "sites"
 		dirs = os.listdir(sites)
 		for dir in dirs:
 			try:
-				f = open(sites+os.sep+dir+os.sep+file)
+				f = open(os.sep.join((sites, dir, file)))
 				list = f.read()
 				f.close()
 				if key in list:
@@ -147,9 +142,9 @@ class Lib3:
 		key = ""
 		defn = []
 		for line in data:
-			if (line.find("<!") == 0):
-				if (key != ""):
-					if (pre): defn = ["<pre>\n"]+defn+["</pre>\n"]
+			if line.startswith("<!"):
+				if key:
+					if pre: defn = ["<pre>\n"] + defn + ["</pre>\n"]
 					parsed_data[key] = defn
 				line = 	self.get_tag(line)
 				key = line
@@ -157,15 +152,15 @@ class Lib3:
 			else:
 				defn.append(line)
 		if (key != ""):
-			if (pre): defn = ["<pre>\n"]+defn+["</pre>\n"]
+			if pre: defn = ["<pre>\n"] + defn + ["</pre>\n"]
 			parsed_data[key] = defn
-		elif (defn != ""):
-			if (pre): defn = ["<pre>\n"]+defn+["</pre>\n"]
+		elif defn:
+			if pre: defn = ["<pre>\n"] + defn + ["</pre>\n"]
 			parsed_data[self.CONTENT] = defn
 		return parsed_data
 
 	def parse_key(self, lines):
-		while (lines[-1].strip() == ""):
+		while not lines[-1].strip():
 			lines = lines[:-1]
 		files = {}
 		order = []
@@ -182,7 +177,7 @@ class Lib3:
 				title = line+"\n"		# XXX make newln go away
 			else:
 				desc = desc+" "+line
-		if (fname != ""):
+		if fname:
 			files[fname] = (title, "".join(desc))
 			order.append(fname)
 		files[self.ORDER] = order
@@ -192,8 +187,8 @@ class Lib3:
 		"""
 		let's you easily print objects in debug mode
 		"""
-		if self.debug:
-			print "<p>::"+label+":: "
+		if debug:
+			print "<p>::" + label + ":: "
 			print msg
 		return
 
@@ -202,7 +197,7 @@ class Lib3:
 		make sure strings in list are in 3.files
 		"""
 		try:
-			f = open(self.FILES)
+			f = open(consts.FILES)
 			files = f.read()
 			f.close()
 			files = files.split("\n")
@@ -210,11 +205,11 @@ class Lib3:
 			files = []
 		changed = 0
 		for entry in list:
-			if (entry not in files):
+			if entry not in files:
 				changed = 1
 				files.append(entry)
-		if (changed):
-			f = open(self.FILES,'w')
+		if changed:
+			f = open(consts.FILES,'w')
 			for file in files:
 				if (file != ""):
 					f.write(file+"\n")
@@ -226,18 +221,18 @@ class Lib3:
 		newln = []
 		tag = 0
 		i = 0
-		while (i < length):
-			if (line[i] == '<'):
+		while i < length:
+			if line[i] == '<':
 				tag = 1
 			if not (tag):
 				newln.append(line[i])
-			if (line[i] == '>'):
+			if line[i] == '>':
 				tag = 0
 				newln.append(" ")
 			i = i + 1
 		newln = "".join(newln).strip()
 		next = ""
-		while (newln != next):
+		while newln != next:
 			next = newln
 			newln = newln.replace("  ", " ")
 		return newln
@@ -248,10 +243,10 @@ class Lib3:
 	def tokens(self, line, sep=" "):
 		tokens = []
 		line = line.strip()
-		if (line != ""):
+		if line:
 			tmp = line.split(sep)
 			for entry in tmp:
-				if (entry != ""):
+				if entry:
 					tokens.append(entry)
 		return tokens
 
@@ -266,6 +261,9 @@ class Lib3:
 				f.write(k+"|"+d[k]+"\n")
 			f.write("---\n")
 			size += int(d["sum"])
-			if (size > self.FILE_MAX): break
+			if size > consts.FILE_MAX: break
 		f.close()
 		return
+
+#-------------------------------------------------------------------------
+lib = Lib3()
\ No newline at end of file
