@@ -20,6 +20,7 @@
 # with this program; if not, write to the Free Software Foundation,
 # Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 
+from TheMingServer import lib
 from PlainParser import PlainParser
 
 class PREParser(PlainParser):
@@ -28,20 +29,17 @@ class PREParser(PlainParser):
 	TITLE = "title"
 	DESC = "desc"
 
-	def __init__(self, lib, debug):
-		PlainParser.__init__(self, lib, debug)
-		self.lib = lib
-		self.debug = debug
-		return
+	def __init__(self):
+		PlainParser.__init__(self)
 
 	def __parse(self, parsed_data):
 		data = parsed_data[self.CONTENT]
 		del parsed_data[self.CONTENT]
 		pre = 1
-		parsed_data = self.lib.parse_data(data, parsed_data, pre)
+		parsed_data = lib.parse_data(data, parsed_data, pre)
 		return parsed_data
 
 	def parse(self, title, desc, data):
 		parsed_data = PlainParser.parse(self, title, desc, data)
 		parsed_data = self.__parse(parsed_data)
-		return parsed_data	
+		return parsed_data
