@@ -26,10 +26,8 @@ class PlainParser:
 	TITLE = "title"
 	DESC = "desc"
 
-	def __init__(self, lib, debug):
-		self.lib = lib
-		self.debug = debug
-		return
+	def __init__(self):
+		pass
 
 	def parse(self, title, desc, data):
 		parsed_data = {
@@ -37,4 +35,4 @@ class PlainParser:
 			self.DESC:desc,
 			}
 		parsed_data[self.CONTENT] = data
-		return parsed_data	
+		return parsed_data
